==> axiom-1.4.0-src.zip: axiom-1.4.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/soap12/faultreason/TestGetFaultReasonText.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.soap12.faultreason;

import static com.google.common.truth.Truth.assertThat;

import java.util.Locale;

import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.soap.SOAPEnvelope;
import org.apache.axiom.soap.SOAPFaultReason;
import org.apache.axiom.ts.soap.SOAPSample;
import org.apache.axiom.ts.soap.SampleBasedSOAPTestCase;

public class TestGetFaultReasonText extends SampleBasedSOAPTestCase {
    public TestGetFaultReasonText(OMMetaFactory metaFactory) {
        super(metaFactory, SOAPSample.SOAP12_FAULT);
    }

    @Override
    protected void runTest(SOAPEnvelope envelope) throws Throwable {
        SOAPFaultReason reason = envelope.getBody().getFault().getReason();
        assertThat(reason.getFaultReasonText(Locale.GERMAN)).isEqualTo("Senderseitige Zeitüberschreitung");
        assertThat(reason.getFaultReasonText(Locale.GERMANY)).isEqualTo("Senderseitige Zeitüberschreitung");
        assertThat(reason.getFaultReasonText(Locale.ENGLISH)).isEqualTo("Sender Timeout");
        assertThat(reason.getFaultReasonText(Locale.FRENCH)).isEqualTo("Sender Timeout");
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/soap12/faultreason/TestGetFaultReasonText.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.soap12.faultreason;

import static com.google.common.truth.Truth.assertThat;

import java.util.Locale;

import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.soap.SOAPEnvelope;
import org.apache.axiom.soap.SOAPFaultReason;
import org.apache.axiom.ts.soap.SOAPSample;
import org.apache.axiom.ts.soap.SampleBasedSOAPTestCase;

public class TestGetFaultReasonText extends SampleBasedSOAPTestCase {
    public TestGetFaultReasonText(OMMetaFactory metaFactory) {
        super(metaFactory, SOAPSample.SOAP12_FAULT);
    }

    @Override
    protected void runTest(SOAPEnvelope envelope) throws Throwable {
        SOAPFaultReason reason = envelope.getBody().getFault().getReason();
        assertThat(reason.getFaultReasonText(Locale.GERMAN))
                .isEqualTo("Senderseitige Zeitüberschreitung");
        assertThat(reason.getFaultReasonText(Locale.GERMANY))
                .isEqualTo("Senderseitige Zeitüberschreitung");
        assertThat(reason.getFaultReasonText(Locale.ENGLISH)).isEqualTo("Sender Timeout");
        assertThat(reason.getFaultReasonText(Locale.FRENCH)).isEqualTo("Sender Timeout");
    }
}
